@@ -1,7 +1,6 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 # Startup from single-user installation
-# Copyright (C) 2002 - 2008 John Goerzen
-# <jgoerzen@complete.org>
+# Copyright (C) 2002-2018 John Goerzen & contributors
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -15,21 +14,11 @@
 #
 #    You should have received a copy of the GNU General Public License
 #    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 
 import os
 import sys
 
-if not 'DEVELOPING_OFFLINEIMAP_PYTHON3_SUPPORT' in os.environ:
-	if sys.version_info[0] > 2:
-		sys.stderr.write("""IIMAPS!
-
-Sorry, OfflineIMAP currently doesn't support Python higher than 2.x.
-We're doing our best to bring in support for 3.x really soon.  You can
-also join us at https://github.com/OfflineIMAP/offlineimap/ and help.
-""")
-		sys.exit(1)
-
 from offlineimap import OfflineImap
 
 oi = OfflineImap()
